import * as Methods from './methods';
/**
 * AsyncArray Class
 *
 * @class AsyncArray
 * @extends {Array<T>}
 * @template T
 */
export declare class AsyncArray<T> extends Array<T> {
    private input;
    /**
     * Creates an instance of AsyncArray
     * @param {...T[]} args
     * @memberof AsyncArray
     */
    constructor(...args: T[]);
    /**
     * Async Filter method
     *
     * @param {Methods.CallBackFilter<T>} cb
     * @returns
     * @memberof AsyncArray
     */
    aFilter(cb: Methods.CallBackFilter<T>): Promise<T[]>;
    /**
     * Async find method
     *
     * @param {Methods.CallBackFind<T>} cb
     * @returns
     * @memberof AsyncArray
     */
    aFind(cb: Methods.CallBackFind<T>): Promise<T | undefined>;
    /**
     * Async ForEach method
     *
     * @param {Methods.CallBackForEach<T>} cb
     * @memberof AsyncArray
     */
    aForEach(cb: Methods.CallBackForEach<T>): Promise<void>;
    /**
     * Async Map method
     *
     * @template R
     * @param {Methods.CallBackMap<T, R>} cb
     * @returns
     * @memberof AsyncArray
     */
    aMap<R>(cb: Methods.CallBackMap<T, R>): Promise<R[]>;
    /**
     * Async Reduce method
     *
     * @template R
     * @param {Methods.CallBackReduce<T, R>} cb
     * @param {*} [initialValue]
     * @returns
     * @memberof AsyncArray
     */
    aReduce<R>(cb: Methods.CallBackReduce<T, R>, initialValue?: any): Promise<R>;
}
